# Package of simple mathematical operations

## Description

This package provides simple math functions for integer and floating-point operations. Includes functions for adding, subtracting, multiplying and dividing both integers and floating point numbers.

## Installation

You can install this package with `pip`:

```bash
pip install FrappePy
```
Use
Functions on integers
Addition
python
```Copy the code
from FrappePy import add_int

result = add_int(5, 3)
print(result) # Output: 8
```
Subtraction
```python
Copy the code
from FrappePy import minus_int

result = minus_int(5, 3)
print(result) # Output: 2
```
Multiplication
```python
Copy the code
from FrappePy import multiply_int

result = multiply_int(5, 3)
print(result) # Output: 15
```
Division
```python
Copy the code
from FrappePy import divide_int

result = divide_int(5, 3)
print(result) # Output: 1.6666666666666667
```
Functions on floating-point numbers
Addition
Copy the code
```py
from FrappePy import add_float
result = add_float(5.0, 3.0)
print(result) # Output: 8.0```

Subtraction
Copy the code
```python
from FrappePy import minus_float
result = minus_float(5.0, 3.0)
print(result) # Output: 2.0
```
Multiplication
```python
Copy the code
from FrappePy import multiply_float

result = multiply_float(5.0, 3.0)
print(result) # Output: 15.0
```
Division
```python
Copy the code
from FrappePy import divide_float

result = divide_float(5.0, 3.0)
print(result) # Output: 1.6666666666666667```